@@ -41,6 +41,10 @@ sub locate_file {
 
     my $path = $env->{PATH_INFO} || '';
 
+    if ($path =~ /\0/) {
+        return $self->return_400;
+    }
+
     my $docroot = $self->root || ".";
     my @path = split '/', $path;
     if (@path) {
@@ -110,6 +114,11 @@ sub return_403 {
     return [403, ['Content-Type' => 'text/plain', 'Content-Length' => 9], ['forbidden']];
 }
 
+sub return_400 {
+    my $self = shift;
+    return [400, ['Content-Type' => 'text/plain', 'Content-Length' => 11], ['Bad Request']];
+}
+
 # Hint: subclasses can override this to return undef to pass through 404
 sub return_404 {
     my $self = shift;
